<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
        <source>Enter the number to configure: </source>
        <translation>Entrer le numéro à configurer :</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation>Chargement des paquets...</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation>%1/%2 chargé</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation>Initialisation...</translation>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="101"/>
        <source>Package Installer</source>
        <translation>Installateur de paquets</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="130"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="537"/>
        <source>Installing other packages... Please open it later.</source>
        <translation>Installation d&apos;autres paquets... Veuillez l&apos;ouvrir plus tard.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="541"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation>Échec de la lecture: Une structure de fichier illégale a été trouvée dans le manifeste.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation>Échec de la lecture: Une numéro de version illégal a été trouvé dans le manifeste.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation>Pas de paquet DEB trouvé. Vérifiez le dossier.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="631"/>
        <source>The deb package may be broken</source>
        <translation>Le paquet deb est peut-être cassé</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="639"/>
        <source>You can only install local deb packages</source>
        <translation>Vous ne pouvez installer que des paquets deb locaux</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="653"/>
        <source>Already Added</source>
        <translation>Déjà ajouté</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="662"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 n&apos;existe pas, veuillez resélectionner </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="330"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="669"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="799"/>
        <source>Bulk Install</source>
        <translation>Installation Multiple</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Échec de l&apos;installation, veuillez vérifier votre connexion réseau</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="89"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>L&apos;installation a échoué, veuillez vérifier les mises à jour dans le centre de contrôle</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="92"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="96"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Échec de l&apos;installation, espace disque insuffisant</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="113"/>
        <source>No digital signature</source>
        <translation>Pas de signature numérique</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="621"/>
        <source>Invalid digital signature</source>
        <translation>Signature numérique non valide</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="614"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1564"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>L&apos;administrateur a défini des politiques pour empêcher l&apos;installation de ce paquet</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="129"/>
        <source>Installation Failed</source>
        <translation>Échec de l&apos;installation</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="623"/>
        <source>Failed to install %1</source>
        <translation>Échec de l&apos;installation de %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="911"/>
        <source>Failed to install %1: no valid digital singature</source>
        <translation>Échec de l&apos;installation de %1 : pas de signature digitale valide</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="949"/>
        <source>Unable to install - no digital signature</source>
        <translation>Impossible d&apos;installer - pas de signature numérique</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="950"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Veuillez accéder au centre de contrôle pour activer le mode développeur et réessayer. Procéder ?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="953"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="954"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>Procéder</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="907"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1009"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1566"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1047"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Ce paquet n&apos;a pas de signature numérique valide. Continuer l&apos;installation ?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1049"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1050"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Continuer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="905"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1006"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1563"/>
        <source>Unable to install</source>
        <translation>Impossible d&apos;installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1007"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Ce paquet n&apos;a pas de signature numérique valide</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="626"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="631"/>
        <source>Broken dependencies: %1</source>
        <translation>Dépendances cassée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="121"/>
        <source>Authentication failed</source>
        <translation>Authentification échouée</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="612"/>
        <source>Unmatched package architecture</source>
        <translation>Architecture de paquet différente</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation>Faites glisser les paquets deb ici</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation>Sélectionner un fichier</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Réduire</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="468"/>
        <source>Dependencies in the repository</source>
        <translation>Dépendances dans le dépôt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="474"/>
        <source>Missing dependencies</source>
        <translation>Dépendances manquantes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Installing dependencies: %1</source>
        <translation>Installation des dépendances : %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>Version identique installée</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Version antérieure installée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Version ultérieure installée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Architecture de paquet différente</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
        <source>Select all</source>
        <translation>Tout sélectionner</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installer</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
        <source>Installing</source>
        <translation>Installation</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
        <source>Installed</source>
        <translation>Installé</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
        <source>Failed</source>
        <translation>Échec</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
        <source>Waiting</source>
        <translation>En attente</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="231"/>
        <source>Same version installed</source>
        <translation>Version identique installée</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>Version ultérieure installée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="237"/>
        <source>Earlier version installed: %1</source>
        <translation>Version antérieure installée : %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="160"/>
        <source>Delete</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Réduire</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Basique</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Vérifier les signatures numériques si le mode développeur est activé</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
        <source>Collapse</source>
        <translation>Réduire</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="806"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="969"/>
        <source>Later version installed: %1</source>
        <translation>Version ultérieure installée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="971"/>
        <source>Downgrade</source>
        <translation>Rétrograder</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="811"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Earlier version installed: %1</source>
        <translation>Version antérieure installée : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="876"/>
        <source>Installing dependencies: %1</source>
        <translation>Installation des dépendances : %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1011"/>
        <source>Failed to install %1</source>
        <translation>Échec de l&apos;installation de %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Version: </source>
        <translation>Version :</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Précédent</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
        <source>Installed successfully</source>
        <translation>Installé avec succès</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
        <source>Uninstalled successfully</source>
        <translation>Désinstallé avec succès</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="698"/>
        <source>Uninstall Failed</source>
        <translation>Échec de la désinstallation</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="727"/>
        <source>Dependencies in the repository</source>
        <translation>Dépendances dans le dépôt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="733"/>
        <source>Missing dependencies</source>
        <translation>Dépendances manquantes</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="813"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="976"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Mettre à jour</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1016"/>
        <source>Invalid digital signature</source>
        <translation>Signature numérique non valide</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
        <source>Name: </source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="802"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="965"/>
        <source>Same version installed</source>
        <translation>Version identique installée</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="678"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Show dependencies</source>
        <translation>Afficher les dépendances</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="683"/>
        <source>Show details</source>
        <translation>Afficher les détails</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>Afficher les paquets associés</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Réduire</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Confirmer</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>Êtes-vous sûr de vouloir désinstaller %1 ?
Toutes les dépendances seront également supprimées.</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>Voulez-vous vraiment désinstaller %1?
Le système ou d&apos;autres applications peuvent ne pas fonctionner correctement</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Installateur de paquets</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>L&apos;installateur de paquets aide les utilisateurs à installer et à supprimer des paquets locaux, prend aussi en charge l&apos;installation multiple.</translation>
    </message>
</context>
</TS>